Rhetoric
=============

.. image:: https://pypip.in/v/Rhetoric/badge.png
        :target: https://crate.io/packages/Rhetoric

.. image:: https://pypip.in/d/Rhetoric/badge.png
        :target: https://crate.io/packages/Rhetoric

Status: **Early Development, Unstable API**.

Naive implementation of Pyramid-like routes for Django projects.
